@@ -113,6 +113,10 @@ class DataTransferGenerator(AWSGenerator):
         row["pricing/term"] = "OnDemand"
         row["pricing/unit"] = "GB"
         row["savingsPlan/SavingsPlanEffectiveCost"] = str(saving)
+
+        # Overwrite lineItem/LineItemType for items with applied Savings plan
+        if saving is not None:
+            row["lineItem/LineItemType"] = "SavingsPlanCoveredUsage"
         self._add_tag_data(row)
         self._add_category_data(row)
         return row
