@@ -136,6 +136,54 @@ OCP_REPORT_TYPE_TO_COLS = {
     OCP_ROS_USAGE: OCP_ROS_USAGE_COLUMN,
 }
 
+# No recommendations are generated for job and manual_pod workloads! Keep these two options as the last two items
+# in the dict to guarantee they are not randomly picked in get_owner_workload function.
+OCP_OWNER_WORKLOAD_CHOICES = {
+    "deployment": (None, "ReplicaSet", None, "deployment"),
+    "replicaset": (None, "ReplicaSet", "<none>", "deployment"),  # manually created ReplicaSet
+    "replicationcontroller": (
+        None,
+        "ReplicationController",
+        "<none>",
+        "deploymentconfig",
+    ),  # manually created ReplicationController
+    "deploymentconfig": (None, "ReplicationController", None, "deploymentconfig"),
+    "statefulset": (None, "StatefulSet", None, "statefulset"),
+    "daemonset": (None, "DaemonSet", None, "daemonset"),
+    "job": (None, "Job", None, "job"),  # not supported by Kruize - recommendation won't be generated!
+    "manual_pod": ("<none>", "<none>", None, None),  # manually created Pod - recommendation won't be generated!
+}
+
+
+def get_owner_workload(pod, workload=None):
+    if not workload:
+        workload = choice(list(OCP_OWNER_WORKLOAD_CHOICES.keys())[:-2])  # omit job and manual_pod from random choices
+    on, ok, wl, wt = OCP_OWNER_WORKLOAD_CHOICES.get(
+        workload.lower(),
+        choice(list(OCP_OWNER_WORKLOAD_CHOICES.values())[:-2]),  # omit job and manual_pod from random choices
+    )
+    if on == "<none>" and wl == "<none>":  # manually created Pod
+        return on, ok, wl, wt
+    elif wl == "<none>":  # manually created ReplicaSet or ReplicationController
+        return pod, ok, wl, wt
+    return pod, ok, pod, wt
+
+
+def generate_randomized_ros_usage(usage_dict, limit_value):
+    # if usage value is provided in yaml -> avg_value = +- 5% of that specified usage value
+    if usage_value := usage_dict.get("full_period"):
+        avg_value = min(round(uniform(usage_value * 0.95, usage_value * 1.05), 5), limit_value)
+    # if usage value is not specified in yaml -> random avg_usage from 10% to 100% of the limit
+    else:
+        avg_value = round(uniform(limit_value * 0.1, limit_value), 5)
+
+    # min value - random float derived from avg_value,
+    min_value = round(uniform(avg_value * 0.8, avg_value), 5)
+    # max_value - random float derived from avg_value, but max of limit_value
+    max_value = min(round(uniform(avg_value, avg_value * 1.2), 5), limit_value)
+
+    return avg_value, min_value, max_value
+
 
 class OCPGenerator(AbstractGenerator):
     """Defines a abstract class for generators."""
@@ -202,7 +250,7 @@ class OCPGenerator(AbstractGenerator):
             self.ocp_report_generation.update(
                 {
                     OCP_ROS_USAGE: {
-                        "_generate_hourly_data": self._gen_hourly_ros_ocp_pods_usage,
+                        "_generate_hourly_data": self._gen_quarter_hourly_ros_ocp_pods_usage,
                         "_update_data": self._update_ros_ocp_pod_data,
                     }
                 }
@@ -350,40 +398,51 @@ class OCPGenerator(AbstractGenerator):
                         "mem_usage_gig": memory_usage_gig,
                         "pod_seconds": specified_pod.get("pod_seconds"),
                     }
+                    owner_name, owner_kind, workload, workload_type = get_owner_workload(
+                        pod, specified_pod.get("workload")
+                    )
+
+                    cpu_usage_avg, cpu_usage_min, cpu_usage_max = generate_randomized_ros_usage(cpu_usage, cpu_limit)
+                    memory_usage_gig_avg, memory_usage_gig_min, memory_usage_gig_max = generate_randomized_ros_usage(
+                        memory_usage_gig, mem_limit_gig
+                    )
+                    memory_rss_ratio = 1 / round(uniform(1.01, 1.9), 2)
+                    cpu_throttle = choices([0, round(cpu_usage_avg / randint(10, 20), 5)], weights=(3, 1))[0]
+
                     ros_ocp_data_pods[pod] = {
                         "namespace": namespace,
                         "node": node.get("name"),
                         "resource_id": node.get("resource_id"),
                         "pod": pod,
                         "container_name": pod,
-                        "owner_name": self.fake.word() + "_" + self.fake.word(),
-                        "owner_kind": self.fake.word() + "_" + self.fake.word(),
-                        "workload": self.fake.word() + "_" + self.fake.word(),
-                        "workload_type": self.fake.word() + "_" + self.fake.word(),
+                        "owner_name": owner_name,
+                        "owner_kind": owner_kind,
+                        "workload": workload,
+                        "workload_type": workload_type,
                         "image_name": self.fake.word() + "-" + self.fake.word(),
-                        "cpu_request_container_avg": randint(75, 100),
-                        "cpu_request_container_sum": randint(25, 75),
-                        "cpu_limit_container_avg": randint(25, 75),
-                        "cpu_limit_container_sum": randint(25, 75),
-                        "cpu_usage_container_avg": randint(25, 75),
-                        "cpu_usage_container_min": randint(0, 25),
-                        "cpu_usage_container_max": randint(75, 100),
-                        "cpu_usage_container_sum": randint(25, 75),
-                        "cpu_throttle_container_avg": randint(25, 75),
-                        "cpu_throttle_container_max": randint(75, 100),
-                        "cpu_throttle_container_sum": randint(25, 75),
-                        "memory_request_container_avg": randint(25, 75),
-                        "memory_request_container_sum": randint(25, 75),
-                        "memory_limit_container_avg": randint(25, 75),
-                        "memory_limit_container_sum": randint(25, 75),
-                        "memory_usage_container_avg": randint(25, 75),
-                        "memory_usage_container_min": randint(0, 25),
-                        "memory_usage_container_max": randint(75, 100),
-                        "memory_usage_container_sum": randint(25, 75),
-                        "memory_rss_usage_container_avg": randint(25, 75),
-                        "memory_rss_usage_container_min": randint(0, 25),
-                        "memory_rss_usage_container_max": randint(75, 100),
-                        "memory_rss_usage_container_sum": randint(25, 75),
+                        "cpu_request_container_avg": cpu_request,
+                        "cpu_request_container_sum": cpu_request,
+                        "cpu_limit_container_avg": cpu_limit,
+                        "cpu_limit_container_sum": cpu_limit,
+                        "cpu_usage_container_avg": cpu_usage_avg,
+                        "cpu_usage_container_min": cpu_usage_min,
+                        "cpu_usage_container_max": cpu_usage_max,
+                        "cpu_usage_container_sum": cpu_usage_avg,
+                        "cpu_throttle_container_avg": cpu_throttle,
+                        "cpu_throttle_container_max": cpu_throttle,
+                        "cpu_throttle_container_sum": cpu_throttle,
+                        "memory_request_container_avg": round(mem_request_gig * GIGABYTE),
+                        "memory_request_container_sum": round(mem_request_gig * GIGABYTE),
+                        "memory_limit_container_avg": round(mem_limit_gig * GIGABYTE),
+                        "memory_limit_container_sum": round(mem_limit_gig * GIGABYTE),
+                        "memory_usage_container_avg": round(memory_usage_gig_avg * GIGABYTE),
+                        "memory_usage_container_min": round(memory_usage_gig_min * GIGABYTE),
+                        "memory_usage_container_max": round(memory_usage_gig_max * GIGABYTE),
+                        "memory_usage_container_sum": round(memory_usage_gig_avg * GIGABYTE),
+                        "memory_rss_usage_container_avg": round(memory_usage_gig_avg * memory_rss_ratio * GIGABYTE),
+                        "memory_rss_usage_container_min": round(memory_usage_gig_min * memory_rss_ratio * GIGABYTE),
+                        "memory_rss_usage_container_max": round(memory_usage_gig_max * memory_rss_ratio * GIGABYTE),
+                        "memory_rss_usage_container_sum": round(memory_usage_gig_avg * memory_rss_ratio * GIGABYTE),
                     }
 
             else:
@@ -400,6 +459,7 @@ class OCPGenerator(AbstractGenerator):
                     memory_gig = memory_bytes / GIGABYTE
                     mem_limit_gig = round(uniform(25.0, memory_gig), 2)
                     mem_request_gig = round(uniform(25.0, mem_limit_gig), 2)
+
                     pods[pod] = {
                         "namespace": namespace,
                         "node": node.get("name"),
@@ -415,40 +475,48 @@ class OCPGenerator(AbstractGenerator):
                         "mem_limit_gig": mem_limit_gig,
                         "pod_labels": self._gen_openshift_labels(),
                     }
+                    owner_name, owner_kind, workload, workload_type = get_owner_workload(pod)
+                    cpu_usage_avg, cpu_usage_min, cpu_usage_max = generate_randomized_ros_usage({}, cpu_limit)
+                    memory_usage_gig_avg, memory_usage_gig_min, memory_usage_gig_max = generate_randomized_ros_usage(
+                        {}, mem_limit_gig
+                    )
+                    memory_rss_ratio = 1 / round(uniform(1.01, 1.9), 2)
+                    cpu_throttle = choices([0, round(cpu_usage_avg / randint(10, 20), 5)], weights=(3, 1))[0]
+
                     ros_ocp_data_pods[pod] = {
                         "namespace": namespace,
                         "node": node.get("name"),
                         "resource_id": node.get("resource_id"),
                         "pod": pod,
                         "container_name": pod,
-                        "owner_name": self.fake.word() + "_" + self.fake.word(),
-                        "owner_kind": self.fake.word() + "_" + self.fake.word(),
-                        "workload": self.fake.word() + "_" + self.fake.word(),
-                        "workload_type": self.fake.word() + "_" + self.fake.word(),
+                        "owner_name": owner_name,
+                        "owner_kind": owner_kind,
+                        "workload": workload,
+                        "workload_type": workload_type,
                         "image_name": self.fake.word() + "-" + self.fake.word(),
-                        "cpu_request_container_avg": randint(75, 100),
-                        "cpu_request_container_sum": randint(25, 75),
-                        "cpu_limit_container_avg": randint(25, 75),
-                        "cpu_limit_container_sum": randint(25, 75),
-                        "cpu_usage_container_avg": randint(25, 75),
-                        "cpu_usage_container_min": randint(0, 25),
-                        "cpu_usage_container_max": randint(75, 100),
-                        "cpu_usage_container_sum": randint(25, 75),
-                        "cpu_throttle_container_avg": randint(25, 75),
-                        "cpu_throttle_container_max": randint(75, 100),
-                        "cpu_throttle_container_sum": randint(25, 75),
-                        "memory_request_container_avg": randint(25, 75),
-                        "memory_request_container_sum": randint(25, 75),
-                        "memory_limit_container_avg": randint(25, 75),
-                        "memory_limit_container_sum": randint(25, 75),
-                        "memory_usage_container_avg": randint(25, 75),
-                        "memory_usage_container_min": randint(0, 25),
-                        "memory_usage_container_max": randint(75, 100),
-                        "memory_usage_container_sum": randint(25, 75),
-                        "memory_rss_usage_container_avg": randint(25, 75),
-                        "memory_rss_usage_container_min": randint(0, 25),
-                        "memory_rss_usage_container_max": randint(75, 100),
-                        "memory_rss_usage_container_sum": randint(25, 75),
+                        "cpu_request_container_avg": cpu_request,
+                        "cpu_request_container_sum": cpu_request,
+                        "cpu_limit_container_avg": cpu_limit,
+                        "cpu_limit_container_sum": cpu_limit,
+                        "cpu_usage_container_avg": cpu_usage_avg,
+                        "cpu_usage_container_min": cpu_usage_min,
+                        "cpu_usage_container_max": cpu_usage_max,
+                        "cpu_usage_container_sum": cpu_usage_avg,
+                        "cpu_throttle_container_avg": cpu_throttle,
+                        "cpu_throttle_container_max": cpu_throttle,
+                        "cpu_throttle_container_sum": cpu_throttle,
+                        "memory_request_container_avg": round(mem_request_gig * GIGABYTE),
+                        "memory_request_container_sum": round(mem_request_gig * GIGABYTE),
+                        "memory_limit_container_avg": round(mem_limit_gig * GIGABYTE),
+                        "memory_limit_container_sum": round(mem_limit_gig * GIGABYTE),
+                        "memory_usage_container_avg": round(memory_usage_gig_avg * GIGABYTE),
+                        "memory_usage_container_min": round(memory_usage_gig_min * GIGABYTE),
+                        "memory_usage_container_max": round(memory_usage_gig_max * GIGABYTE),
+                        "memory_usage_container_sum": round(memory_usage_gig_avg * GIGABYTE),
+                        "memory_rss_usage_container_avg": round(memory_usage_gig_avg * memory_rss_ratio * GIGABYTE),
+                        "memory_rss_usage_container_min": round(memory_usage_gig_min * memory_rss_ratio * GIGABYTE),
+                        "memory_rss_usage_container_max": round(memory_usage_gig_max * memory_rss_ratio * GIGABYTE),
+                        "memory_rss_usage_container_sum": round(memory_usage_gig_avg * memory_rss_ratio * GIGABYTE),
                     }
 
         return pods, namespace2pod, ros_ocp_data_pods
@@ -587,14 +655,15 @@ class OCPGenerator(AbstractGenerator):
 
         cpu_request = min(pod.pop("cpu_request"), cpu_limit)
         mem_request_gig = min(pod.pop("mem_request_gig"), mem_limit_gig)
-
         cpu_usage = self._get_usage_for_date(kwargs.get("cpu_usage"), start)
         cpu = round(uniform(0.02, cpu_limit), 5)
+        # ensure that cpu usage is not higher than cpu_limit
         if cpu_usage:
             cpu = min(cpu_limit, cpu_usage)
 
         mem_usage_gig = self._get_usage_for_date(kwargs.get("mem_usage_gig"), start)
         mem = round(uniform(1, mem_limit_gig), 2)
+        # ensure that mem usage is not higher than mem_limit
         if mem_usage_gig:
             mem = min(mem_limit_gig, mem_usage_gig)
 
@@ -702,23 +771,16 @@ class OCPGenerator(AbstractGenerator):
                     row = self._update_data(row, start, end, pod=pod, **kwargs)
                     yield row
 
-    def _gen_hourly_ros_ocp_pods_usage(self, **kwargs):
+    def _gen_quarter_hourly_ros_ocp_pods_usage(self, **kwargs):
         """Create hourly data for pod usage."""
-        for hour in self.hours:
-            start = hour.get("start")
-            end = hour.get("end")
+        for quarter_hour in self.quarter_hours:
+            start = quarter_hour.get("start")
+            end = quarter_hour.get("end")
             if self._nodes:
                 for pod_name, _ in self.pods.items():
-                    pod = deepcopy(self.pods[pod_name])
+                    pod = deepcopy(self.ros_data[pod_name])
                     row = self._init_data_row(start, end, **kwargs)
-                    row = self._update_data(
-                        row,
-                        start,
-                        end,
-                        pod=pod,
-                        **kwargs,
-                    )
-                    yield row
+                    yield self._update_data(row, start, end, pod=pod, **kwargs)
             else:
                 pod_count = len(self.pods)
                 num_pods = randint(2, pod_count)
@@ -729,8 +791,7 @@ class OCPGenerator(AbstractGenerator):
                     pod_name = pod_keys[pod_choice]
                     pod = deepcopy(self.ros_data[pod_name])
                     row = self._init_data_row(start, end, **kwargs)
-                    row = self._update_data(row, start, end, pod=pod, **kwargs)
-                    yield row
+                    yield self._update_data(row, start, end, pod=pod, **kwargs)
 
     def _gen_hourly_storage_usage(self, **kwargs):
         """Create hourly data for storage usage."""
