@@ -789,6 +789,7 @@ def ocp_create_report(options):  # noqa: C901
             data.update({OCP_ROS_USAGE: []})
             file_numbers.update({OCP_ROS_USAGE: 0})
         monthly_files = []
+        monthly_ros_files = []
         for generator in generators:
             generator_cls = generator.get("generator")
             attributes = generator.get("attributes")
@@ -833,19 +834,35 @@ def ocp_create_report(options):  # noqa: C901
                 report_type,
                 data[report_type],
             )
-            monthly_files.append(month_output_file)
+            if report_type == OCP_ROS_USAGE:
+                monthly_ros_files.append(month_output_file)
+            else:
+                monthly_files.append(month_output_file)
 
         if insights_upload:
             # Generate manifest for all files
             ocp_assembly_id = uuid4()
             report_datetime = gen_start_date
             temp_files = {}
+            temp_ros_files = {}
             for num_file in range(len(monthly_files)):
                 temp_filename = f"{ocp_assembly_id}_openshift_report.{num_file}.csv"
-                temp_usage_file = create_temporary_copy(monthly_files[num_file], temp_filename, "payload")
-                temp_files[temp_filename] = temp_usage_file
+                temp_files[temp_filename] = create_temporary_copy(monthly_files[num_file], temp_filename, "payload")
+
+            for num_file in range(len(monthly_ros_files)):
+                temp_filename = f"{ocp_assembly_id}_openshift_report.{num_file + len(monthly_files)}.csv"
+                temp_ros_files[temp_filename] = create_temporary_copy(
+                    monthly_ros_files[num_file], temp_filename, "payload"
+                )
 
             manifest_file_names = ", ".join(f'"{w}"' for w in temp_files)
+            if not temp_ros_files:
+                manifest_ros_data = None
+            elif len(temp_ros_files) == 1:
+                (key,) = temp_ros_files.keys()
+                manifest_ros_data = f"{key}"
+            else:
+                manifest_ros_data = ", ".join(f'"{w}"' for w in temp_ros_files)[1:-1]
             cr_status = {
                 "clusterID": "4e009161-4f40-42c8-877c-3e59f6baea3d",
                 "clusterVersion": "stable-4.6",
@@ -884,6 +901,7 @@ def ocp_create_report(options):  # noqa: C901
                 "ocp_assembly_id": ocp_assembly_id,
                 "report_datetime": report_datetime,
                 "files": manifest_file_names[1:-1],
+                "ros_files": manifest_ros_data,
                 "start": gen_start_date,
                 "end": gen_end_date,
                 "version": __version__,
@@ -902,11 +920,19 @@ def ocp_create_report(options):  # noqa: C901
                 os.remove(temp_usage_file)
                 os.remove(temp_usage_zip)
 
+            for temp_usage_file in temp_ros_files.values():
+                ros_report_files = [temp_usage_file, temp_manifest_name]
+                temp_usage_zip = _tar_gzip_report_files(ros_report_files)
+                ocp_route_file(insights_upload, temp_usage_zip)
+                os.remove(temp_usage_file)
+                os.remove(temp_usage_zip)
+
             os.remove(temp_manifest)
             os.remove(temp_manifest_name)
         if not write_monthly:
             LOG.info("Cleaning up local directory")
             _remove_files(monthly_files)
+            _remove_files(monthly_ros_files)
 
 
 def write_gcp_file(start_date, end_date, data, options):
@@ -1139,50 +1165,68 @@ def _gcp_bigquery_process(
     return monthly_files
 
 
+def oci_generate_report_name(report_name_options):
+    """return generated oci report name"""
+
+    file_num = report_name_options.get("file_num")
+    month = report_name_options.get("month")
+    year = report_name_options.get("year")
+    report_type = report_name_options.get("report_type")
+
+    month_num = f"0{month}" if month < 10 else month
+    file_name = f"report_{report_type}-{file_num}_{year}-{month_num}.csv"
+    absolute_report_name = f"{os.getcwd()}/{file_name}"
+    return absolute_report_name
+
+
 def oci_route_file(report_type, month, year, data, options):
     """Route file to either local file system or OCI bucket."""
 
     bucket_name = options.get("oci_bucket_name")
     file_name = ""
+    filename_options = {
+        "file_num": options.get("file_num", randint(1000, 9999)),
+        "month": month,
+        "year": year,
+        "report_type": report_type,
+    }
+    absolute_report_name = oci_generate_report_name(filename_options)
     if bucket_name is None:
-        file_name = oci_write_file(report_type, month, year, data, options)
+        file_name = oci_write_file(report_type, absolute_report_name, data, options)
     else:
-        file_name = oci_bucket_upload(bucket_name, report_type, month, year, data, options)
+        file_name = oci_bucket_upload(bucket_name, report_type, absolute_report_name, data, options)
     return file_name
 
 
-def oci_write_file(report_type, month, year, data, options):
+def oci_write_file(report_type, absolute_report_name, data, options):
     """Write OCI data to a file."""
-    month_num = f"0{month}" if month < 10 else month
-    file_name = f"report_{report_type}-0001_{year}-{month_num}.csv"
-    full_file_name = f"{os.getcwd()}/{file_name}"
-    _write_csv(full_file_name, data, OCI_REPORT_TYPE_TO_COLS[report_type])
 
+    _write_csv(absolute_report_name, data, OCI_REPORT_TYPE_TO_COLS[report_type])
     local_bucket = options.get("oci_local_bucket")
+    report_path, report_name = os.path.split(absolute_report_name)
     if local_bucket:
         if not os.path.isdir(local_bucket):
             os.mkdir(local_bucket)
-        copy_to_local_dir(local_bucket, full_file_name, file_name)
-    return full_file_name
+        copy_to_local_dir(local_bucket, absolute_report_name, report_name)
+    return report_name
 
 
-def oci_bucket_upload(bucket_name, report_type, month, year, data, options):
-
+def oci_bucket_upload(bucket_name, report_type, absolute_report_name, data, options):
     """Upload data to OCI bucket."""
-    month_num = f"0{month}" if month < 10 else month
-    file_name = f"report_{report_type}-0001_{year}-{month_num}.csv"
-    full_file_name = f"{os.getcwd()}/{file_name}"
-    _write_csv(full_file_name, data, OCI_REPORT_TYPE_TO_COLS[report_type])
+
+    _write_csv(absolute_report_name, data, OCI_REPORT_TYPE_TO_COLS[report_type])
     _report_type = f"{report_type}-csv"
-    upload_to_oci_bucket(bucket_name, _report_type, file_name)
-    return file_name
+    report_path, report_name = os.path.split(absolute_report_name)
+    upload_to_oci_bucket(bucket_name, _report_type, report_name)
+    return report_name
 
 
 def oci_create_report(options):
     """Create cost and usage report files."""
 
+    generate_daily_report = options.get("oci_daily_report", False)
     start_date = options.get("start_date")
-    end_date = options.get("end_date")
+    end_date = start_date if generate_daily_report else options.get("end_date")
     static_report_data = options.get("static_report_data")
 
     if static_report_data:
